
import sys


import wwsclient
from wwsclient import client
from wwsclient import service
from wwsclient import util


def main():  # type: () -> None
    pass

if __name__ == "__main__":
    main()
